Search.setIndex({envversion:43,objnames:{},titles:["Debugging","Excentury Format","Installing Excentury","Excentury Documentation","What is excentury?"],filenames:["cpp/debug","format","installation","index","excentury"],objects:{},titleterms:{excenturi:[1,3,2,4],format:1,exitif:0,what:4,debug:0,nix:2,level:0,multidimension:1,api:[],document:3,indic:3,execut:2,arrai:1,tensor:1,trace:0,wai:2,tabl:3,multidiment:[],summari:1,system:2,welcom:[],instal:2,basic:[1,3],usag:3,exampl:[],easi:2,file:1,type:1,structur:1},objtypes:{},terms:{line:[0,1,2],could:[0,1],number:[1,2],simplic:1,mention:1,"float":1,befor:0,matrix_nam:1,execut:[],second:1,when:[0,1],sign:1,want:[0,1],messag:[0,2],here:1,chosen:1,each:[0,1],dure:0,repres:1,letter:1,notic:0,space:0,thu:1,satisfi:0,would:1,doe:1,yet:2,futur:0,hello:[0,1],test:0,integr:[3,4],sudo:2,know:1,more:[1,2],fail:0,follow:[0,1,2],possibl:1,moment:1,matlab:[1,3,2,4],inform:1,halt:0,mai:[0,1],dictionari:1,structur:[],search:3,seen:0,exitif:[],run2:0,real:1,turn:0,look:[0,1],written:[3,4],becaus:0,store:1,left:[],other:[0,1],august:3,token:1,tell:1,doubl:1,overcom:1,variabl:1,seamlessli:1,describ:[1,2],did:[],"long":1,mean:[0,1],"class":1,perman:0,facilit:0,"new":1,should:[0,1],problem:1,provid:0,column:1,displai:0,tar:2,exit:0,trace:[],similarli:1,two:1,outsid:0,version:[3,2,4],check:0,can:[0,1,2],compil:0,just:1,sinc:[0,1,2],reli:1,memori:[0,1],block:1,function_cal:0,differenti:0,"case":[0,1],global:2,assum:1,result:0,abl:[0,1,2],known:1,str_obj:1,"char":1,see:[0,1,2],origin:1,ani:0,give:1,under:2,includ:[0,2],string:1,"byte":1,abrutli:0,those:0,piec:1,matric:1,serial:1,treat:1,realli:0,than:2,"int":[0,1],along:1,out:[0,1],usual:[0,1],"while":[0,1],your:[0,2],notat:1,after:1,contain:1,care:2,expect:1,suppos:1,address:0,you:[0,2],easi:[],segment:0,state:1,well:[0,1,2],tool:0,option:2,without:0,correctli:0,continu:1,"final":1,load:1,how:1,user:[0,2],all:[0,1,2],defin:0,done:[0,1],occur:0,onli:[0,4],build:1,"true":0,content:1,languag:[1,3,4],soon:[0,1],condit:0,consid:[0,1],minimum:1,resourc:1,necessari:1,explor:0,wget:2,amount:1,sourc:2,idea:[0,1],print:[0,2],been:1,perform:2,cpp:0,instal:[],temporari:0,aid:0,design:0,set:0,setup:2,either:[0,1],definit:1,dimens:1,routin:0,three:0,line_obj:1,sai:1,process:1,off:0,represent:1,xvzf:2,begin:[],behav:0,minumum:[],matrix:1,examin:1,scription:3,gener:[],specifi:1,"function":0,sequenc:1,row:1,file:0,access:[0,2],easiest:2,task:0,also:2,which:[0,1],have:[0,1,2],word:1,detect:0,"catch":0,later:1,valu:[0,1],part:1,resort:0,ddebug:0,world:[0,1],them:[0,1],member:1,actual:[0,1],point:1,common:0,datatyp:1,"short":1,pip:2,macro:0,explain:0,declar:1,"public":1,must:[1,2],verifi:2,everi:1,wish:[1,2],integ:1,run1:0,momemnt:[],python3:2,form:1,output:[],printf:0,pair:1,allow:[0,3,4],wast:1,point_obj:1,some:2,behind:1,first:1,instanc:1,avail:2,simpli:1,activ:0,initi:[],commun:1,binari:[],librari:[3,2,4],inclus:0,understand:1,enabl:4,read:1,brief:1,admin:2,occurr:0,org:2,natur:1,essenti:1,from:[0,2],between:[0,1],script:[1,2,4],introduct:1,current:4,expand:0,caught:0,let:1,cover:1,element:1,howev:1,previou:1,path:2,consum:0,replac:[0,2],last:[0,1,2],index:3,adapt:1,write:[0,1],built:3,code:1,error:0,right:2,might:1,directori:2,locat:0,call:[0,1,2],python:[1,3,2,4],collect:[3,4],thi:[0,1,3,2],find:[0,1],now:[1,2],page:3,packag:2,taught:1,make:2,again:0,were:0,statement:0,array_nam:1,denot:1,data:1,fault:0,time:[0,1],command:[0,2],taken:2,modul:3,account:2,http:2,better:0,techniqu:0,show:1,evalut:0,take:[0,1,2],run3:0,previous:1,charact:1,requir:1,order:[0,1],need:[0,1],pypi:2,worldn:[],similari:[],assign:1,correct:1,sure:2,ccc:[],main:[0,1],guess:[],sever:[0,1,3,2,4],work:1,major:1,run:[0,1],decid:1,size:1,section:1,hand:0,program:[0,1],given:1,"null":0,end:0,where:[1,2],special:1,mani:0,"try":[0,2],object:1,writer:[],meant:0,unsign:1,name:1,made:1,noth:0,most:0,enough:0,help:[0,1,2]}})